![CI](https://github.com/ComputationalPhysiology/mps_motion/workflows/CI/badge.svg)
[![Publish documentation](https://github.com/ComputationalPhysiology/mps_motion/actions/workflows/deploy_docs.yml/badge.svg)](https://github.com/ComputationalPhysiology/mps_motion/actions/workflows/deploy_docs.yml)
[![PyPI version](https://badge.fury.io/py/mps-motion.svg)](https://badge.fury.io/py/mps-motion)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![DOI](https://zenodo.org/badge/327848546.svg)](https://zenodo.org/doi/10.5281/zenodo.13380032)

# MPS Motion

Library for tracking motion in cardiac mps data


* Source code: https://github.com/ComputationalPhysiology/mps_motion
* Documentation: https://computationalphysiology.github.io/mps_motion


## Installation

See: https://computationalphysiology.github.io/mps_motion/install.html


## Getting started

See https://computationalphysiology.github.io/mps_motion/quickstart.html


## Authors

- Henrik Finsberg henriknf@simula.no

## Citing
If you use this library in your research, please cite the following paper
```
@article{10.1088/2057-1976/ad7268,
	author={Finsberg, Henrik Nicolay Topnes and Charwat, Verena and Healy, Kevin E and Wall, Samuel},
	title={Automatic motion estimation with applications to hiPSC-CMs},
	journal={Biomedical Physics & Engineering Express},
	url={http://iopscience.iop.org/article/10.1088/2057-1976/ad7268},
	year={2024},
}
```

## License
MIT
